# Real Market Analysis Report\n\n**Generated**: 2025-11-22 14:49:04\n\n**Analysis Period**: 2023-01-01 to 2024-01-01\n\n## Executive Summary\n\nAnalyzed 3 stocks using Hidden Markov Model regime detection.\n\n### AAPL Analysis\n\n- **Current Regime**: Bear\n- **Confidence**: 0.0%\n- **Data Period**: 249 days\n\n#### Regime Distribution\n\n- **Bear**: 249 days (100.0%)\n\n#### Performance by Regime\n\n- **Bear**:\n  - Mean Daily Return: 0.180%\n  - Daily Volatility: 1.258%\n  - Sharpe Ratio: 0.14\n\n### MSFT Analysis\n\n- **Current Regime**: Bear\n- **Confidence**: 0.0%\n- **Data Period**: 249 days\n\n#### Regime Distribution\n\n- **Bear**: 249 days (100.0%)\n\n#### Performance by Regime\n\n- **Bear**:\n  - Mean Daily Return: 0.216%\n  - Daily Volatility: 1.559%\n  - Sharpe Ratio: 0.14\n\n### SPY Analysis\n\n- **Current Regime**: Bear\n- **Confidence**: 0.0%\n- **Data Period**: 249 days\n\n#### Regime Distribution\n\n- **Bear**: 249 days (100.0%)\n\n#### Performance by Regime\n\n- **Bear**:\n  - Mean Daily Return: 0.096%\n  - Daily Volatility: 0.825%\n  - Sharpe Ratio: 0.12\n\n## Methodology\n\nThis analysis uses a 3-state Hidden Markov Model to detect market regimes:\n\n- **Bear Market**: Declining prices with high volatility\n- **Sideways Market**: Range-bound prices with low volatility\n- **Bull Market**: Rising prices with moderate volatility\n\nThe model analyzes log returns to identify regime patterns and transitions.\n\n